| Positive and unit sum constrained least squares | R Documentation |
Positive and unit sum constrained least squares.
pcls(y, x)
mpcls(y, x)
y |
The response variable. For the pcls() a numerical vector with observations, but for the mpcls() a numerical matrix. |
x |
A matrix with independent variables, the design matrix. |
The constraint is that all beta coefficients are positive and sum to 1. that is
min \sum_{i=1}^n(y_i-\bm{x}_i\top\bm{\beta})^2 such that 0\leq \beta_j \leq 1 and \sum_{j=1}^d\beta_j=1. The pcls() function performs a single regression model, whereas the mpcls() function performs a regression for each column of y. Each regression is independent of the others.
A list including:
be |
A numerical matrix with the positively constrained beta coefficients. |
mse |
A numerical vector with the mean squared error. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
pls, cls, mvpls
x <- as.matrix( iris[1:50, 1:4] )
y <- abs( rnorm(50) )
pcls(y, x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.